searchData={"items":[{"type":"module","title":"HL7","doc":"Functions to manipulate and query HL7 documents -- plus a way to handle HL7 file streams.","ref":"HL7.html"},{"type":"function","title":"HL7.chunk_by_lead_segment/3","doc":"Creates a list of lists in which the specified `segment_name` is used to get the first segment map\nof each list. This function helps to do things like grouping `OBX` segments with their parent `OBR` segment.\n\nOptions:\n\n`keep_prefix_segments: true` will leave the first set of non-matching segments in the return value.","ref":"HL7.html#chunk_by_lead_segment/3"},{"type":"function","title":"HL7.do_to_list/1","doc":"","ref":"HL7.html#do_to_list/1"},{"type":"function","title":"HL7.get/2","doc":"Finds data within an `HL7.t()` and from within the data that `get/2` returns (segments and repetitions)\nusing an `HL7.Path` sigil.\n\nSelecting data across multiple segments or repetitions with the wildcard `[*]` pattern\nwill return a list of results.\n\nRepetition data can be search using a partial path containing ony the component and/or\nsubcomponent with the preceding period, e.g. `~p\".2.3\"`.","ref":"HL7.html#get/2"},{"type":"function","title":"Examples - HL7.get/2","doc":"iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX-5\")\n    \"1.80\"\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX[*]-5\")\n    [\"1.80\", \"79\"]\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX[*]-2!\")\n    [\"N\", \"NM\"]\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID-11[*].5\")\n    [\"35209\", \"35200\"]\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID-11[2].1\")\n    \"NICKELL’S PICKLES\"\n\n    iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID-11[*]\")\n    ...> |> HL7.get(~p\".1\")\n    [\"260 GOODWIN CREST DRIVE\", \"NICKELL’S PICKLES\"]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX[*]\")\n    [\n      %{\n        0 => \"OBX\",\n        1 => \"1\",\n        2 => %{1 => %{1 => \"N\", 2 => %{1 => \"K\", 2 => \"M\"}}},\n        3 => %{1 => %{2 => \"Body Height\"}},\n        5 => \"1.80\",\n        6 => %{1 => %{1 => \"m\", 2 => \"Meter\", 3 => \"ISO+\"}},\n        11 => \"F\"\n      },\n      %{\n        0 => \"OBX\",\n        1 => \"2\",\n        2 => \"NM\",\n        3 => %{1 => %{2 => \"Body Weight\"}},\n        5 => \"79\",\n        6 => %{1 => %{1 => \"kg\", 2 => \"Kilogram\", 3 => \"ISO+\"}},\n        11 => \"F\"\n      }\n    ]","ref":"HL7.html#get/2-examples"},{"type":"function","title":"HL7.get_segments/1","doc":"","ref":"HL7.html#get_segments/1"},{"type":"function","title":"HL7.label/2","doc":"Labels source data (a segment map or list of segment maps) by using `HL7.Path` sigils in a labeled\noutput template.\n\nOne-arity functions placed as output template values will be called with the source data.","ref":"HL7.html#label/2"},{"type":"function","title":"Examples - HL7.label/2","doc":"iex> import HL7, only: :sigils\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.label(%{mrn: ~p\"PID-3!\", name: ~p\"PID-5.2\"})\n    %{mrn: \"56782445\", name: \"BARRY\"}","ref":"HL7.html#label/2-examples"},{"type":"function","title":"HL7.new/1","doc":"","ref":"HL7.html#new/1"},{"type":"function","title":"HL7.new!/1","doc":"Creates an HL7 struct from HL7 data (accepting text, lists or the deprecated `HL7.Message` struct).","ref":"HL7.html#new!/1"},{"type":"function","title":"HL7.open_hl7_file_stream/2","doc":"Opens an HL7 file stream of either `:mllp` or `:line`. If the file_type is not specified\nit will be inferred from the first three characters of the file contents.","ref":"HL7.html#open_hl7_file_stream/2"},{"type":"function","title":"HL7.put/3","doc":"","ref":"HL7.html#put/3"},{"type":"function","title":"HL7.set_segments/2","doc":"","ref":"HL7.html#set_segments/2"},{"type":"macro","title":"HL7.sigil_p/2","doc":"The `~p` sigil encodes an HL7 path into a struct at compile-time to guarantee correctness and speed.\nIt is designed to work with data returned by `HL7.new!/1`.\n\nThe full path structure in HL7 is expressed as:\n\n`~p\"SEGMENT_NAME[SEGMENT_NUMBER]-FIELD[REPETITION].COMPONENT.SUBCOMPONENT`\n\n`SEGMENT_NAME` -- 3 character string\n`SEGMENT_NUMBER` -- Positive integer in brackets, defaulting to 1. All segments of the name can be accessed with `[*]`\n`FIELD` -- Positive integer\n`REPETITION` -- Positive integer in brackets, defaulting to 1. All repetitions of the field can be accessed with `[*]`\n`COMPONENT` -- Positive integer\n`SUBCOMPONENT` -- Positive integer\n\nExample paths:\n\n`~p\"OBX\"` refers to the 1st OBX segment in its entirety, the same as `~p\"OBX[1]\"`.\n`~p\"OBX-5\"` means the 1st repetition of the 5th field of the 1st OBX segment.\n`~p\"OBX[1]-5[1]\"` is equivalent, the numbers in brackets specifying the default repetition and segment number values.\n`~p\"OBX[2]-5\"` thus means 1st repetition of the 5th field of the 2nd OBX segment.\n`~p\"OBX[*]-5\"` would get the 1st repetition of the 5th field of every OBX segment, returning a list of results.\n\nNote that repetitions are uncommon in HL7 and the default of a 1st repetition is often just assumed.\n`~p\"PID-3\"` is equivalent to `~p\"PID-3[1]\"` and is the most standard representation.\n\nAll repetitions can be found using a repetition wildcard: `~p\"PID-11[*]\"`. A list of lists can\nbe produced by selecting multiple segments and multiple repetitions with `~p\"PID[*]-11[*]\"`.\n\nComponents and subcomponents can also be accessed with the path structures.\n`h\"OBX-2.3.1\"` would return the 1st subcomponent of the 3rd component of the 2nd field of the 1st OBX.\n\nAdditionally, if a path might have additional data such that a string might be found at either\n`~p\"OBX-2\"` or `~p\"OBX-2.1\"` or even `~p\"OBX-2.1.1\"`, there is truncation character (the bang symbol) that\nwill return the first element found in the HL7 text at the target specificity. Thus, `~p\"OBX[*]-2!\"`\nwould get the 1st piece of data in the 2nd field of every OBX whether it is a string or nested map.\n\nLastly, when accessing data from a specific repetition, the path should begin with `.`; for example,\nwhen working with the Nth OBX segment and using `HL7.get/2` to access that segment's second field, first\ncomponent, use the path `~p\".2.1\"`","ref":"HL7.html#sigil_p/2"},{"type":"macro","title":"Examples - HL7.sigil_p/2","doc":"iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX-5\")\n    \"1.80\"\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX[*]-5\")\n    [\"1.80\", \"79\"]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"OBX[*]-2!\")\n    [\"N\", \"NM\"]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID-11[*].5\")\n    [\"35209\", \"35200\"]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID[*]-11[*].5\")\n    [[\"35209\", \"35200\"]]\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID-11[2].1\")\n    \"NICKELL’S PICKLES\"\n\n    iex> import HL7\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(~p\"PID-11[*]\")\n    ...> |> List.last()\n    ...> |> HL7.get(~p\".1\")\n    \"NICKELL’S PICKLES\"","ref":"HL7.html#sigil_p/2-examples"},{"type":"function","title":"HL7.to_list/1","doc":"Converts a segment map (or lists of segments maps) or HL7 struct into a raw Elixir list.","ref":"HL7.html#to_list/1"},{"type":"function","title":"HL7.update/4","doc":"","ref":"HL7.html#update/4"},{"type":"function","title":"HL7.update!/3","doc":"","ref":"HL7.html#update!/3"},{"type":"type","title":"HL7.file_type_hl7/0","doc":"","ref":"HL7.html#t:file_type_hl7/0"},{"type":"type","title":"HL7.hl7_list_data/0","doc":"","ref":"HL7.html#t:hl7_list_data/0"},{"type":"type","title":"HL7.hl7_map_data/0","doc":"","ref":"HL7.html#t:hl7_map_data/0"},{"type":"type","title":"HL7.parsed_hl7/0","doc":"","ref":"HL7.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.parsed_hl7_segments/0","doc":"","ref":"HL7.html#t:parsed_hl7_segments/0"},{"type":"type","title":"HL7.segment/0","doc":"","ref":"HL7.html#t:segment/0"},{"type":"type","title":"HL7.t/0","doc":"","ref":"HL7.html#t:t/0"},{"type":"module","title":"HL7.Examples","doc":"Functions to provide sample HL7 data which can be used to explore the API.","ref":"HL7.Examples.html"},{"type":"function","title":"HL7.Examples.elr_example/0","doc":"","ref":"HL7.Examples.html#elr_example/0"},{"type":"function","title":"HL7.Examples.nist_immunization_hl7/0","doc":"","ref":"HL7.Examples.html#nist_immunization_hl7/0"},{"type":"function","title":"HL7.Examples.nist_syndromic_hl7/0","doc":"","ref":"HL7.Examples.html#nist_syndromic_hl7/0"},{"type":"function","title":"HL7.Examples.wikipedia_sample_hl7/1","doc":"Returns a sample HL7 string from [Wikipedia's HL7 article](https://en.wikipedia.org/wiki/Health_Level_7#Version_2_messaging).\n\nThe HL7 version of the message defaults to 2.5, but can be overidden.","ref":"HL7.Examples.html#wikipedia_sample_hl7/1"},{"type":"function","title":"HL7.Examples.wikipedia_sample_hl7_alt_delimiters/0","doc":"","ref":"HL7.Examples.html#wikipedia_sample_hl7_alt_delimiters/0"},{"type":"module","title":"HL7.Header","doc":"An HL7 header implementation that can be used to build MSH segments and HL7 messages.\nIt is also exposed as metadata after parsing any HL7 message.","ref":"HL7.Header.html"},{"type":"function","title":"HL7.Header.get_message_date_time/0","doc":"","ref":"HL7.Header.html#get_message_date_time/0"},{"type":"function","title":"HL7.Header.get_message_type_field/1","doc":"","ref":"HL7.Header.html#get_message_type_field/1"},{"type":"function","title":"HL7.Header.new/5","doc":"","ref":"HL7.Header.html#new/5"},{"type":"function","title":"HL7.Header.to_msh/1","doc":"","ref":"HL7.Header.html#to_msh/1"},{"type":"type","title":"HL7.Header.t/0","doc":"","ref":"HL7.Header.html#t:t/0"},{"type":"module","title":"HL7.InvalidHeader","doc":"Contains information concerning any failed attempt to parse an HL7 MSH segment.","ref":"HL7.InvalidHeader.html"},{"type":"type","title":"HL7.InvalidHeader.t/0","doc":"","ref":"HL7.InvalidHeader.html#t:t/0"},{"type":"module","title":"HL7.Path","doc":"","ref":"HL7.Path.html"},{"type":"function","title":"HL7.Path.new/1","doc":"Generates an `~p` sigil data structure at runtime.","ref":"HL7.Path.html#new/1"},{"type":"function","title":"Examples - HL7.Path.new/1","doc":"iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.new!()\n    ...> |> HL7.get(HL7.Path.new(\"OBX-5\"))\n    \"1.80\"","ref":"HL7.Path.html#new/1-examples"},{"type":"type","title":"HL7.Path.level/0","doc":"","ref":"HL7.Path.html#t:level/0"},{"type":"type","title":"HL7.Path.t/0","doc":"","ref":"HL7.Path.html#t:t/0"},{"type":"module","title":"HL7.FieldGrammar","doc":"Represents an HL7 path.","ref":"HL7.FieldGrammar.html"},{"type":"function","title":"HL7.FieldGrammar.to_indices/1","doc":"","ref":"HL7.FieldGrammar.html#to_indices/1"},{"type":"module","title":"HL7.InvalidMessage","doc":"Contains information concerning any failed attempt\nto parse an HL7 message, generally MSH-related","ref":"HL7.InvalidMessage.html"},{"type":"type","title":"HL7.InvalidMessage.t/0","doc":"","ref":"HL7.InvalidMessage.html#t:t/0"},{"type":"module","title":"HL7.Message","doc":"Creates, parses and modifies HL7 messages with a focus on performance. Contains a list of parsed segments and header metadata.\n\nUse `HL7.Message.new/2` to create an `t:HL7.Message.t/0` struct that contains a fully parsed HL7 message alongside header metadata.\nThe parsed data is represented as minimally as possible as lists of string and lists.\n\n\nThe second argument is an options map supporting the following values:\n\n`copy: true` -- Will create binary copies while parsing to avoid keeping references.\n\n`validate_string: true` -- Will generate an `HL7.InvalidMessage` if the source text is not UTF-8 compatible.","ref":"HL7.Message.html"},{"type":"function","title":"HL7.Message.find/2","doc":"Returns the first parsed segment matching `segment_name` from an HL7 message or content.","ref":"HL7.Message.html#find/2"},{"type":"function","title":"HL7.Message.new/2","doc":"Creates an `HL7.Message` struct containing parsed segment list data. It will\nalso expose basic header information (e.g. encoding characters, message type) for routing.\n\nPass `copy: true` as the second argument to generate binary copies of all substrings as it parses the message.\n\nInvalid MSH formats will return an `HL7.InvalidMessage`.","ref":"HL7.Message.html#new/2"},{"type":"function","title":"Examples - HL7.Message.new/2","doc":"iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.Message.new()\n    ...> |> HL7.Query.get_segment_names()\n    [\"MSH\", \"EVN\", \"PID\", \"PV1\", \"OBX\", \"OBX\", \"AL1\", \"DG1\"]\n\n    iex> HL7.Message.new(\n    ...>   \"MSH|^~\\\\&|MegaReg|XYZHospC|SuperOE|XYZImgCtr|\" <>\n    ...>   \"20060529090131-0500||ADT^A01^ADT_A01|01052901|P|2.5\")\n    ...> |> HL7.Query.get_segment_names()\n    [\"MSH\"]\n\n    iex> HL7.Message.new(\n    ...>   [[\"MSH\", \"|\", \"^~\\\\&\", \"App\", \"Facility\", \"\", \"\",\n    ...>     \"20060529090131-0500\", \"\", [[\"ADT\", \"A01\", \"ADT_A01\"]],\n    ...>     \"01052901\", \"P\", \"2.5\"]])\n    ...> |> HL7.Query.get_segment_names()\n    [\"MSH\"]","ref":"HL7.Message.html#new/2-examples"},{"type":"function","title":"HL7.Message.raw/1","doc":"Creates an `HL7.Message` struct containing the raw HL7 text for further processing. It will\nalso expose basic header information (e.g. encoding characters, message type) for routing.\n\nInvalid MSH formats will return an `HL7.InvalidMessage` struct.","ref":"HL7.Message.html#raw/1"},{"type":"function","title":"HL7.Message.to_list/1","doc":"Returns a parsed list of segments from an HL7 message or content.","ref":"HL7.Message.html#to_list/1"},{"type":"type","title":"HL7.Message.content_hl7/0","doc":"","ref":"HL7.Message.html#t:content_hl7/0"},{"type":"type","title":"HL7.Message.fragment_hl7/0","doc":"","ref":"HL7.Message.html#t:fragment_hl7/0"},{"type":"type","title":"HL7.Message.parsed_hl7/0","doc":"","ref":"HL7.Message.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.Message.raw_hl7/0","doc":"","ref":"HL7.Message.html#t:raw_hl7/0"},{"type":"type","title":"HL7.Message.segment_hl7/0","doc":"","ref":"HL7.Message.html#t:segment_hl7/0"},{"type":"type","title":"HL7.Message.t/0","doc":"","ref":"HL7.Message.html#t:t/0"},{"type":"module","title":"HL7.Query","doc":"Queries and modifies HL7 messages using Field and Segment Grammar Notations with a pipeline-friendly API and set-based\noperations.\n\nSimilar to libraries such as jQuery and D3, `HL7.Query` is designed around the concept of selecting and sub-selecting\nelements (segments or segment groups) in an HL7 message. The full message context is retained in the `HL7.Query`\nstruct so that messages can be modified piecemeal and then reconstructed as strings.\n\nIn general, use `HL7.Query.select/2` with a segment selector (similar to CSS selectors) to select lists of segment groups.\n\nThe segment selector is written as a string of ordered segment names. Curly braces surround repeating elements.\nSquare brackets enclose optional elements. These can be nested to create selectors that can select complex groups of segments or validate\nentire HL7 message layouts.\n\nFor example, an ORU_R01 HL7 message's Order Group selector could be written as:\n\n`\"[ORC] OBR {[NTE]} {[OBX {[NTE]}]}\"`.\n\nNote that this would look for OBRs, optionally preceded by an ORC, possibly followed by one or more NTEs, maybe followed\nagain by one or more OBRs with their own optional NTE sets.\n\nTo reference data within segments, there is a field selector format that can access fields, repetitions, components\nand sub-components across one or more segments. All indices start at one, and the repetition index defaults to one\nunless specified within brackets after the field number.\n\nField Selector | Description\n------------ | -------------\n`\"PID-11[2].4\"` | PID segments, 11th field, 2nd repetition, 4th component\n`\"OBX-2.2.1\"` | OBX segments, 2nd field, 2nd component, 1st sub-component\n`\"1\"` | All segments, 1st field\n`\"3[4].2\"` | All segments, 3rd field, 4th repetition, 2nd component","ref":"HL7.Query.html"},{"type":"function","title":"HL7.Query.append/2","doc":"Appends a segment or segments to the currently _selected_ segments in each selection.","ref":"HL7.Query.html#append/2"},{"type":"function","title":"HL7.Query.count/1","doc":"Returns the current selection count.","ref":"HL7.Query.html#count/1"},{"type":"function","title":"HL7.Query.data/2","doc":"Associates data with each selection. This data remains accessible to\nchild selections.\n\nEach selection stores a map of data. The supplied `fun` should\naccept an `HL7.Query` and return a map of key-values to be merged into the\nexisting map of data.\n\nSelections automatically include the index of the current selection, i.e., `%{index: 5}`.\nFor HL7 numbering, the index values begin at 1.","ref":"HL7.Query.html#data/2"},{"type":"function","title":"Examples - HL7.Query.data/2","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC RXA RXR {[OBX]}\")\n    ...> |> data(fn q -> %{order_num: find_first(q, ~p\"ORC-3.1\")} end)\n    ...> |> select(\"OBX\")\n    ...> |> update(~p\"6\", fn q -> get_datum(q, :order_num) end)\n    ...> |> root()\n    ...> |> find_first(~p\"OBX-6\")\n    \"IZ-783278\"\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC RXA RXR {[OBX]}\")\n    ...> |> data(fn q -> %{group_num: get_index(q)} end)\n    ...> |> select(\"OBX\")\n    ...> |> update(~p\"6\", fn q -> get_datum(q, :group_num) end)\n    ...> |> root()\n    ...> |> find_all(~p\"OBX-6\")\n    [1, 1, 1, 1, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2]","ref":"HL7.Query.html#data/2-examples"},{"type":"function","title":"HL7.Query.delete/1","doc":"Deletes all selections in the query document.","ref":"HL7.Query.html#delete/1"},{"type":"function","title":"HL7.Query.filter/2","doc":"Filters (deletes) segments within selections by whitelisting one or more segment types.\nAccepts either a segment name, list of acceptable names, or a function that takes an `HL7.Query`\n(containing one sub-selected segment at a time) and returns a boolean filter value.","ref":"HL7.Query.html#filter/2"},{"type":"function","title":"Examples - HL7.Query.filter/2","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> filter([\"MSH\", \"PID\", \"ORC\"])\n    ...> |> root()\n    ...> |> get_segment_names()\n    [\"MSH\", \"PID\", \"ORC\", \"ORC\", \"ORC\"]","ref":"HL7.Query.html#filter/2-examples"},{"type":"function","title":"HL7.Query.find_all/2","doc":"Returns a flattened list of segment parts from _selected_ segments across all selections using\nthe given `field_selector`.\n\n`PID-3[2].1.2` PID segments, field 3, repetition 2, component 1, subcomponent 2\n\n`OBX-5` OBX segments, field 5\n\n`2.3` All segments, field 2, component 3","ref":"HL7.Query.html#find_all/2"},{"type":"function","title":"HL7.Query.find_first/2","doc":"Returns a segment part from the first _selected_ segment (of the given name, if specified)\nacross all selections using the given `field_selector`.\n\n`PID-3[2].1.2` PID segments, field 3, repetition 2, component 1, subcomponent 2\n\n`OBX-5` OBX segments, field 5\n\n`2.3` All segments, field 2, component 3","ref":"HL7.Query.html#find_first/2"},{"type":"function","title":"HL7.Query.get_data/1","doc":"Returns a list containing an associated data map for each selection in the given `HL7.Query`.","ref":"HL7.Query.html#get_data/1"},{"type":"function","title":"HL7.Query.get_datum/3","doc":"Returns the associated key-value of the first (or only) selection for the given `HL7.Query`.","ref":"HL7.Query.html#get_datum/3"},{"type":"function","title":"HL7.Query.get_index/1","doc":"Returns the selection index of the first (or only) selection for the given `HL7.Query`.","ref":"HL7.Query.html#get_index/1"},{"type":"function","title":"Examples - HL7.Query.get_index/1","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC RXA RXR {[OBX]}\")\n    ...> |> map(fn q -> get_index(q) end)\n    [1, 2]\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC RXA RXR {[OBX]}\")\n    ...> |> select(\"OBX\")\n    ...> |> map(fn q -> get_index(q) end)\n    [1, 2, 3, 4, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"OBX\")\n    ...> |> map(fn q -> get_index(q) end)\n    [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14]","ref":"HL7.Query.html#get_index/1-examples"},{"type":"function","title":"HL7.Query.get_part/2","doc":"","ref":"HL7.Query.html#get_part/2"},{"type":"function","title":"HL7.Query.get_parts/2","doc":"","ref":"HL7.Query.html#get_parts/2"},{"type":"function","title":"HL7.Query.get_segment_groups/1","doc":"Returns a list containing a list of _selected_ segments for each selection.","ref":"HL7.Query.html#get_segment_groups/1"},{"type":"function","title":"HL7.Query.get_segment_names/1","doc":"Returns a flattened list of segment names across all selections.","ref":"HL7.Query.html#get_segment_names/1"},{"type":"function","title":"HL7.Query.get_segments/1","doc":"Returns a flattened list of _selected_ segments across all selections.","ref":"HL7.Query.html#get_segments/1"},{"type":"function","title":"HL7.Query.map/2","doc":"Maps across each selection with a `fun` that accepts an `HL7.Query`\n(handling one selection at a time) and returns a results list.","ref":"HL7.Query.html#map/2"},{"type":"function","title":"Examples - HL7.Query.map/2","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"RXA\")\n    ...> |> map(fn q -> find_first(q, ~p\"5.2\") end)\n    [\"Influenza\", \"PCV 13\", \"DTaP-Hep B-IPV\"]","ref":"HL7.Query.html#map/2-examples"},{"type":"function","title":"HL7.Query.new/1","doc":"Creates an `HL7.Query` struct that selects an entire HL7 Message. This step is implicitly carried out by most other\nfunctions in this module. As it involves parsing an HL7 message, one should\ncache this result if invoked repeatedly.","ref":"HL7.Query.html#new/1"},{"type":"function","title":"HL7.Query.number_set_ids/1","doc":"Updates the set numbers in each segment's first field to be their respective selection indices.","ref":"HL7.Query.html#number_set_ids/1"},{"type":"function","title":"HL7.Query.prepend/2","doc":"Prepends a segment or list of segments to the segments in each of the current selections.","ref":"HL7.Query.html#prepend/2"},{"type":"function","title":"HL7.Query.reject/2","doc":"Rejects (deletes) segments within selections by blacklisting one or more segment types.\nAccepts either a segment name, list of acceptable names, or a function that takes an `HL7.Query`\n(containing one sub-selected segment at a time) and returns a boolean reject value.","ref":"HL7.Query.html#reject/2"},{"type":"function","title":"Examples - HL7.Query.reject/2","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> reject([\"OBX\", \"RXA\", \"RXR\"])\n    ...> |> root()\n    ...> |> get_segment_names()\n    [\"MSH\", \"PID\", \"ORC\", \"ORC\", \"ORC\"]","ref":"HL7.Query.html#reject/2-examples"},{"type":"function","title":"HL7.Query.reject_z_segments/1","doc":"Rejects (deletes) Z-segments in all selections.","ref":"HL7.Query.html#reject_z_segments/1"},{"type":"function","title":"HL7.Query.replace/2","doc":"Replaces all segments in each selection. The given `fun` should\naccept an `HL7.Query` (referencing a single selection) and return a list of replacement segments\n(in parsed list format).","ref":"HL7.Query.html#replace/2"},{"type":"function","title":"HL7.Query.replace_parts/3","doc":"","ref":"HL7.Query.html#replace_parts/3"},{"type":"function","title":"HL7.Query.root/1","doc":"Selects the entire an `HL7.Query` into an `HL7.Message`.","ref":"HL7.Query.html#root/1"},{"type":"function","title":"HL7.Query.select/2","doc":"Selects or sub-selects segment groups in an HL7 message using a segment selector or filter function.\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"OBX\")\n    ...> |> select(fn q -> find_first(q, ~p\"1\") != \"1\" end)\n    ...> |> delete()\n    ...> |> root()\n    ...> |> get_segment_names()\n    [\"MSH\", \"PID\", \"ORC\", \"RXA\", \"RXR\", \"OBX\", \"ORC\", \"RXA\", \"ORC\", \"RXA\", \"RXR\", \"OBX\"]","ref":"HL7.Query.html#select/2"},{"type":"macro","title":"HL7.Query.sigil_g/2","doc":"","ref":"HL7.Query.html#sigil_g/2"},{"type":"macro","title":"HL7.Query.sigil_p/2","doc":"Checks the format of an hl7 path at compile time and returns an Path","ref":"HL7.Query.html#sigil_p/2"},{"type":"function","title":"HL7.Query.to_console/1","doc":"Outputs an ANSI representation of an `HL7.Query` with corresponding selection indices on the left.","ref":"HL7.Query.html#to_console/1"},{"type":"function","title":"HL7.Query.to_message/1","doc":"Converts an `HL7.Query` into an `HL7.Message`.","ref":"HL7.Query.html#to_message/1"},{"type":"function","title":"HL7.Query.update/3","doc":"Updates segment parts of all selected segments, iterating through each selection.\nA replacement function accepts an `HL7.Query` containing one selection with its\n`part` property set to the value found using the `field_selector`.","ref":"HL7.Query.html#update/3"},{"type":"function","title":"Examples - HL7.Query.update/3","doc":"iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> update(~p\"OBX-3.2\", fn q -> \"TEST: \" <> q.part end)\n    ...> |> find_all(~p\"OBX-3.2\")\n    ...> |> List.first()\n    \"TEST: Vaccine funding program eligibility category\"\n\n    iex> import HL7.Query\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> select(\"PID\")\n    ...> |> update(~p\"5.2\", \"UNKNOWN\")\n    ...> |> find_first(~p\"PID-5.2\")\n    \"UNKNOWN\"","ref":"HL7.Query.html#update/3-examples"},{"type":"type","title":"HL7.Query.content_hl7/0","doc":"","ref":"HL7.Query.html#t:content_hl7/0"},{"type":"type","title":"HL7.Query.content_or_query_hl7/0","doc":"","ref":"HL7.Query.html#t:content_or_query_hl7/0"},{"type":"type","title":"HL7.Query.parsed_hl7/0","doc":"","ref":"HL7.Query.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.Query.parsed_or_query_hl7/0","doc":"","ref":"HL7.Query.html#t:parsed_or_query_hl7/0"},{"type":"type","title":"HL7.Query.raw_hl7/0","doc":"","ref":"HL7.Query.html#t:raw_hl7/0"},{"type":"type","title":"HL7.Query.t/0","doc":"","ref":"HL7.Query.html#t:t/0"},{"type":"module","title":"HL7.RawMessage","doc":"Contains the raw text of an HL7 message alongside parsed header metadata from the MSH segment.\n\nUse `HL7.Message.raw/1` to generate the `t:HL7.RawMessage.t/0` struct","ref":"HL7.RawMessage.html"},{"type":"type","title":"HL7.RawMessage.t/0","doc":"","ref":"HL7.RawMessage.html#t:t/0"},{"type":"module","title":"HL7.Segment","doc":"Filter, parse and modify individual HL7 segments and their fragments.","ref":"HL7.Segment.html"},{"type":"function","title":"HL7.Segment.get_part/5","doc":"Extracts content from a parsed HL7 segment,\nreturning nested data by applying each supplied index in turn. Please note that HL7 indices start at 1.","ref":"HL7.Segment.html#get_part/5"},{"type":"function","title":"HL7.Segment.leftmost_value/1","doc":"","ref":"HL7.Segment.html#leftmost_value/1"},{"type":"function","title":"HL7.Segment.replace_part/6","doc":"Updates content within a parsed HL7 segment, returning a modified segment whose data has been transformed at the given\nindices (starting at 1 as with HL7's convention). The `transform` can be either a `string`, `list` or `fn old_data -> new_data`.","ref":"HL7.Segment.html#replace_part/6"},{"type":"type","title":"HL7.Segment.content_hl7/0","doc":"","ref":"HL7.Segment.html#t:content_hl7/0"},{"type":"type","title":"HL7.Segment.fragment_hl7/0","doc":"","ref":"HL7.Segment.html#t:fragment_hl7/0"},{"type":"type","title":"HL7.Segment.parsed_hl7/0","doc":"","ref":"HL7.Segment.html#t:parsed_hl7/0"},{"type":"type","title":"HL7.Segment.raw_hl7/0","doc":"","ref":"HL7.Segment.html#t:raw_hl7/0"},{"type":"type","title":"HL7.Segment.segment_hl7/0","doc":"","ref":"HL7.Segment.html#t:segment_hl7/0"},{"type":"module","title":"HL7.Separators","doc":"Contains HL7 delimiter information (optionally specified by the end system) used to parse or generate HL7 messages.","ref":"HL7.Separators.html"},{"type":"function","title":"HL7.Separators.new/1","doc":"","ref":"HL7.Separators.html#new/1"},{"type":"function","title":"HL7.Separators.new/2","doc":"","ref":"HL7.Separators.html#new/2"},{"type":"type","title":"HL7.Separators.t/0","doc":"","ref":"HL7.Separators.html#t:t/0"},{"type":"extras","title":"Elixir HL7","doc":"# Elixir HL7 \n[![hex.pm version](https://img.shields.io/hexpm/v/elixir_hl7.svg)](https://hex.pm/packages/elixir_hl7) \n[![hex.pm downloads](https://img.shields.io/hexpm/dt/elixir_hl7.svg)](https://hex.pm/packages/elixir_hl7)\n[![hex.pm license](https://img.shields.io/hexpm/l/elixir_hl7.svg)](https://hex.pm/packages/elixir_hl7)\n\nAn Elixir library for working with HL7 v2.x healthcare data \n\nElixir HL7 provides functions to parse, query and modify healthcare data that conforms to the HL7 v2.x standards. \nIt should be able to reconstruct any HL7 Message without data loss or corruption.\n\nIt also provides basic support for reading HL7 file streams with configurable delimiters (MLLP included). \n\nThis library has been tested on a fairly wide variety of real-world HL7 messages to ensure correctness and flexibility. \n\nYou can learn more about HL7 here:\n* The official HL7 website ([hl7.org](http://www.hl7.org/index.cfm))\n* Wikipedia's [HL7 article](https://en.wikipedia.org/wiki/Health_Level_7) \n\nPlease [report an issue](https://github.com/HCA-Healthcare/elixir-hl7/issues) if something appears to be handled incorrectly.\n\n>","ref":"readme.html"},{"type":"extras","title":"Note {: .warning} - Elixir HL7","doc":">\n>\n> We are building a simpler and more Elixir-friendly API for this library, centered on\n> the `HL7` and `HL7.Path` modules. \n> \n> The new API will lead to the deprecation of `HL7.Query` and related code. \n> \n> These will likely not be removed for some time, and their\n> removal will coincide with a major version release. For now, the two systems can exchange data when needed.","ref":"readme.html#note-warning"},{"type":"extras","title":"Getting started - Elixir HL7","doc":"Add this library to your mix.exs file:\n\n```elixir\ndefp deps do\n  [{:elixir_hl7, \"~> 0.9.2\"}]\nend\n```","ref":"readme.html#getting-started"},{"type":"extras","title":"Use the Tabs Below to Explore the Library - Elixir HL7","doc":"<!-- tabs-open -->","ref":"readme.html#use-the-tabs-below-to-explore-the-library"},{"type":"extras","title":"Examples - Elixir HL7","doc":"The `HL7.Examples` module contains functions with sample data that you can use in unit tests or to explore the API,\n\n    iex> hl7_text = HL7.Examples.wikipedia_sample_hl7()\n    ...> to_string()\n    ...> Enum.take(30)\n    \"ADT\"","ref":"readme.html#examples"},{"type":"extras","title":"Route - Elixir HL7","doc":"HL7 messages can be minimally validated to gather header (MSH segment) information for quick routing and acknowledgements.\n\n    iex> hl7_text = HL7.Examples.wikipedia_sample_hl7()\n    ...> raw_msg = HL7.Message.raw(hl7_text)\n    ...> raw_msg.header.message_type\n    \"ADT\" \n\nSee the `HL7.RawMessage` and `HL7.Header` modules for more information.","ref":"readme.html#route"},{"type":"extras","title":"Parse - Elixir HL7","doc":"HL7 messages can be fully parsed into lists of lists and strings to provide a compact representation of the message structure.\n\nOne could grab the 2nd segment in a message:\n\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.Message.to_list()\n    ...> |> Enum.at(1)\n    [\"EVN\", \"\", \"200605290901\", \"\", \"\", \"\", \"200605290900\"]\n\nOr get the field value of RXA-5.2 (finding the first RXA segment's 5th field, 1st repetition, 2nd component):\n\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> HL7.Message.find(\"RXA\")\n    ...> |> HL7.Segment.get_part(5, 1, 2)\n    \"Influenza\"\n   \nIt's also possible to modify the data within a segment (but it is much easier to manipulate messages using the `HL7.Query` module):\n\n    iex> HL7.Examples.wikipedia_sample_hl7()\n    ...> |> HL7.Message.find(\"EVN\")\n    ...> |> HL7.Segment.replace_part(\"extra data\", 5, 2, 1)\n    [      \n      \"EVN\",\n      \"\",\n      \"200605290901\",\n      \"\",\n      \"\",\n      [\"\", \"\", [\"\", \"extra data\"]],\n      \"200605290900\"\n    ]\n        \nSee the `HL7.Message` and `HL7.Segment` modules for more information.","ref":"readme.html#parse"},{"type":"extras","title":"Query - Elixir HL7","doc":"Advanced manipulation and analysis of HL7 messages can be performed with the `HL7.Query` module. \n\nIt supports a pipeline-friendly API modeled after jQuery and D3, allowing set-based document operations and queries.\n\nMessages can be broken into groups using a segment selector (similar to a CSS selector string) that denotes optional and repeating segments in potentially nested hierarchies. \n\nIndividual segments can be decomposed using a field selector to reference specific field, repetition, component and subcomponent indices.  \n\nNote that all `HL7.Query` selections implicitly retain the entire message structure such that elements can be selected, modified and then used to reconstruct a new HL7 message.    \n\nThe act of selecting something never modifies the content of a message. Applying other methods to a selection, such as delete, filter, append, etc., does modify the actual message content.\n\nFor instance, this would select all textual diagnoses (DG1-3.2) associated with a patient visit (PV1):\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_syndromic_hl7()\n    ...> |> select(\"PV1 [{DG1}]\")\n    ...> |> select(\"DG1\")\n    ...> |> find_all(~p\"3.2\")\n    [\"Cryptosporidiosis\", \"Dehydration\", \"Diarrhea\"]\n    \nThe statement `select(\"PV1 [{DG1}]\")` grabs a list of segment groups containing a PV1 segment and any DG1 segments that might follow it.\nThus, we would select one group containing a PV1 segment and three DG1 segments.    \n\n```elixir\n[ \n  [ # 1 group of 4 segments\n    [\"PV1\", \"1\", \"(data truncated to fit)\"],\n    [\"DG1\", \"1\", \"\", [[\"0074\", \"Cryptosporidiosis\", \"I9CDX\"]], \"\", \"\", \"F\"],\n    [\"DG1\", \"2\", \"\", [[\"27651\", \"Dehydration\", \"I9CDX\"]], \"\", \"\", \"F\"],\n    [\"DG1\", \"3\", \"\", [[\"78791\", \"Diarrhea\", \"I9CDX\"]], \"\", \"\", \"F\"]\n  ]\n]\n```\n\nThen `select(\"DG1\")` creates three groups of individual DG1 segments by searching within the confines of the prior selection.\n\n```elixir\n[  # 3 groups of 1 segment each\n  [[\"DG1\", \"1\", \"\", [[\"0074\", \"Cryptosporidiosis\", \"I9CDX\"]], \"\", \"\", \"F\"]],\n  [[\"DG1\", \"2\", \"\", [[\"27651\", \"Dehydration\", \"I9CDX\"]], \"\", \"\", \"F\"]],\n  [[\"DG1\", \"3\", \"\", [[\"78791\", \"Diarrhea\", \"I9CDX\"]], \"\", \"\", \"F\"]]\n]\n```\n\nFinally, `find_all(~p\"3.2\")` will return a flattened list of data containing the 3rd field, 1st repetition (the default), 2nd component for each\n selected segment.\n  \n```elixir\n[\"Cryptosporidiosis\", \"Dehydration\", \"Diarrhea\"]\n```\n    \nAlternately, one could select and remove every diagnosis tied to a patient visit and then output a modified HL7 message:\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_syndromic_hl7()\n    ...> |> select(\"PV1 [{DG1}]\")\n    ...> |> select(\"DG1\")\n    ...> |> delete()\n    ...> |> to_string()\n    \"MSH|^~\\\\&||LakeMichMC^9879874000^NPI|||201204020040||ADT^A03^ADT_A03|NIST-SS-003.32|P|2.5.1|||||||||PH_SS-NoAck^SS Sender^2.16.840.1.114222.4.10.3^ISO\\rEVN||201204020030|||||LakeMichMC^9879874000^NPI\\rPID|1||33333^^^^MR||^^^^^^~^^^^^^S|||F||2106-3^^CDCREC|^^^^53217^^^^55089|||||||||||2186-5^^CDCREC\\rPV1|1||||||||||||||||||33333_001^^^^VN|||||||||||||||||09||||||||201204012130\\rOBX|1|CWE|SS003^^PHINQUESTION||261QE0002X^Emergency Care^NUCC||||||F\\rOBX|2|NM|21612-7^^LN||45|a^^UCUM|||||F\\rOBX|3|CWE|8661-1^^LN||^^^^^^^^Diarrhea, stomach pain, dehydration||||||F\\r\"  \n\nThe following query extracts each Common Order (ORC) group's OBX segments and outputs a list of each order's associated vaccine types.\n\n    iex> import HL7.Query\n    iex> HL7.Examples.nist_immunization_hl7()\n    ...> |> select(\"ORC [RXA] [RXR] {OBX}\")\n    ...> |> filter(fn q -> find_first(q, ~p\"3.2\") == \"vaccine type\" end)\n    ...> |> map(fn q -> find_all(q, ~p\"5.2\") end)\n    [\n        [\"Influenza, unspecified formulation\"], \n        [\"DTaP\", \"Polio\", \"Hep B, unspecified formulation\"]\n    ]   \n\n   \nSee the `HL7.Query` module for more information.","ref":"readme.html#query"},{"type":"extras","title":"Create - Elixir HL7","doc":"HL7 messages can be constructed from scratch with the `HL7.Message` module. Passing an `HL7.Header` struct to\n`HL7.Message.new/1` will produce a base message upon which you can add additional segments. These can be appended as list data. \n\nThe final raw message can be produced by invoking the `to_string/1` protocol on either the `HL7.Query` or `HL7.Message` structs.\n\n<!-- tabs-close -->","ref":"readme.html#create"},{"type":"extras","title":"Files - Elixir HL7","doc":"The `HL7` module contains utility functions to open file streams of HL7 message content with support for MLLP and standard `:line` storage. \nOther formats are somewhat supported by specifying expected prefix and suffix delimiters between messages.","ref":"readme.html#files"},{"type":"extras","title":"Sockets - Elixir HL7","doc":"A separate library, Elixir-MLLP, exists to manage MLLP connections. MLLP is a simple protocol on top of TCP that is commonly used for sending and receiving HL7 messages.","ref":"readme.html#sockets"},{"type":"extras","title":"Status - Elixir HL7","doc":"This project is approaching a v1.0 release. The API is mostly stable at this point. \n\nAlso, please be aware of the details of the license (Apache 2.0). \n\n# Roadmap\n\nExtending the `HL7` base namespace to provide a simpler and more powerful API.\n\n# License\n\nElixir-HL7 source code is released under Apache 2 License. Check the LICENSE file for more information.","ref":"readme.html#status"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}